@@ -11,9 +11,8 @@ package MBX::Alien::FLTK;
     sub new {
         my ($class, %args) = @_;
         shift;
-        my $self     = $class->SUPER::new(@_);
-        my $OS       = $args{'osname'} || $Config{'osname'} || $^O;
-        my $CC       = $args{'cc'} || $Config{'ccname'} || $Config{'cc'};
+        my $OS = $args{'osname'} || $Config{'osname'} || $^O;
+        my $CC = $args{'cc'}     || $Config{'ccname'} || $Config{'cc'};
         my @platform = grep defined, $OS =~ m[Win32]
             ? (
             'Windows',
@@ -25,11 +24,17 @@ package MBX::Alien::FLTK;
              : ()                              # Hope for the best
             )
             )
-            : $OS =~ m[Darwin]i  ? 'Darwin'     # Mac OSX
-            : $OS =~ m[BSD$]i    ? 'BSD'        # requires GNUmake (gmake)
-            : $OS =~ m[Solaris]i ? 'Solaris'    # requires GNUmake (gmake)
-            : $OS =~ m[IRIX]i    ? 'IRIX'       # requires GNUmake (gmake)
-            :                      'Unix';
+            : $OS =~ m[CygWin]i ? (qw[Windows CygWin])    # ...baka
+            : (
+            'Unix',
+            ($OS =~ m[Darwin]i
+             ? 'Darwin'                                   # Mac OSX
+             : $OS =~ m[BSD$]i    ? 'BSD'
+             : $OS =~ m[Solaris]i ? 'Solaris'
+             : $OS =~ m[IRIX]i    ? 'IRIX'
+             : ()
+            )
+            );
         my $platform = 'MBX::Alien::FLTK::Platform';
         for my $qual (@platform) {
             $platform .= '::' . $qual;
@@ -37,9 +42,11 @@ package MBX::Alien::FLTK;
             next if $@;
             unshift @ISA, $platform;
         }
+        my $self = $class->SUPER::new(@_);
         $self->notes(platform => \@platform);
         $self->notes(os       => $OS);
         $self->notes(cc       => $CC);
+        $self->notes(errors   => []);
         return $self;
     }
 
@@ -55,7 +62,6 @@ package MBX::Alien::FLTK;
         }
         return $self;
     }
-    sub VERBOSE { shift->notes('verbose') }
     1;
 }
 
@@ -81,6 +87,6 @@ Creative Commons Attribution-Share Alike 3.0 License. See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: FLTK.pm af23f6c 2009-09-01 14:10:31Z sanko@cpan.org $
+=for git $Id: FLTK.pm a97e5a4 2009-10-25 14:34:56Z sanko@cpan.org $
 
 =cut
